<?php
/*
 * Adds tabs and options to ACF interfaces
 */
defined( 'ABSPATH' ) || exit;

/**
 * Adds a tab to the ACF Fields Group settings.
 *
 * @since 1.0.0
 */
add_filter( 'acf/field_group/additional_group_settings_tabs', 'it_acfforms_field_group_tab' );
function it_acfforms_field_group_tab( $tabs ) {
    $tabs['it-acfforms'] = esc_html__( 'Frontend Form', 'it-acfforms' );
    return $tabs;
}

/**
 * Adds fields to the Fields Group tab.
 *
 * @since 1.0.0
 */
add_action( 'acf/field_group/render_group_settings_tab/it-acfforms', 'it_acfforms_field_group_tab_content' );
function it_acfforms_field_group_tab_content( $field_group ) {
	acf_render_field_wrap(
		array(
			'type'         => 'true_false',
			'name'         => 'it_acfforms_active',
			'key'          => 'it_acfforms_active',
			'prefix'       => 'acf_field_group',
			'value'        => isset( $field_group['it_acfforms_active'] ) ? $field_group['it_acfforms_active'] : 1,
			'label'        => esc_html__( 'Display on the frontend form', 'it-acfforms' ),
			'instructions' => esc_html__( 'If the field group is inactive ("Group settings" tab), it will not be displayed on the frontend form even if it is activated here.', 'it-acfforms' ),
			'ui'           => true,
			'default'      => 1,
		)
	);
}

/**
 * Adds a tab to the media fields.
 *
 * @since 1.0.0
 */
add_filter( 'acf/field_group/additional_field_settings_tabs', 'it_acfforms_field_tab' );
function it_acfforms_field_tab( $tabs ) {
    $tabs['it-acfforms'] = esc_html__( 'Private media', 'it-acfforms' );
    return $tabs;
}

/**
 * Adds fields to the Media fields tab.
 *
 * @since 1.0.0
 */
add_action( 'acf/field_group/render_field_settings_tab/it-acfforms/type=image', 'it_acfforms_field_tab_content' );
add_action( 'acf/field_group/render_field_settings_tab/it-acfforms/type=gallery', 'it_acfforms_field_tab_content' );
add_action( 'acf/field_group/render_field_settings_tab/it-acfforms/type=file', 'it_acfforms_field_tab_content' );
function it_acfforms_field_tab_content( $field ) {
	acf_render_field_setting(
		$field,
		array(
			'type'         => 'true_false',
			'name'         => 'it_acfforms_limit_media',
			'label'        => esc_html__( 'Limit the media library’s choice to those of the author', 'it-acfforms' ),
			'instructions' => esc_html__( 'Editors and administrators will always have access to all media.', 'it-acfforms' ) .'<br>'.
			esc_html__( 'This option can be used with or without limiting the media to those uploaded to post ("General" tab).', 'it-acfforms' ),
			'ui'           => 1,
			'wrapper'      => array(
				'style'    => 'border: none;',
			),
		)
	);
}
