<?php
defined( 'ABSPATH' ) || exit;
?>

<h4><?php esc_html_e( 'Overview', 'it-acfforms' ); ?></h4>

<p><?php esc_html_e( 'Several Post properties can be modified by the form, if they are supported by the Post Type. Choose between inserting the default field, using a custom field or not displaying (i.e. not allowing modification by the form).', 'it-acfforms' ); ?></p>

<ul class="ul-disc">
	<li><?php printf(
		esc_html__( '%s: except for the title and editor displayed at the very top, the field is inserted in an ACF field group at position 10 (not visible in ACF settings). If other field groups are inserted with ACF, the order number allows them to be displayed before or after.', 'it-acfforms' ),
		'<strong>'. esc_html__( 'Insert default field', 'it-acfforms' ) .'</strong>'
	); ?></li>
	<li><?php printf(
		esc_html__( '%1$s: select the key of the meta data to be used. Meta keys can be those of ACF fields displayed in the form, but also those of non-displayed ACF fields or metadata recorded in other ways. Respect the expected return values, %2$s.', 'it-acfforms' ),
		'<strong>'. esc_html__( 'Choose a custom field', 'it-acfforms' ) .'</strong>',
		'<a href="#expected-values">'. esc_html__( 'see below for more information', 'it-acfforms' ) .'</a>'
	); ?></li>
	<li><?php printf(
		esc_html__( '%1$s: %2$s.', 'it-acfforms' ),
		'<strong>'. esc_html__( 'Enter a fixed value or use substitution variables', 'it-acfforms' ) .'</strong>',
		'<a href="#substitute">'. esc_html__( 'see below for more information', 'it-acfforms' ) .'</a>'
	); ?></li>
</ul>

<p><?php printf(
	esc_html__( 'The %s action can be used to act after the plugin has saved the data.', 'it-acfforms' ),
	'<code>it_acfforms_after_save_post</code>'
); ?></p>

<p class="description"><?php esc_html_e( 'Fields linked to unsupported publication properties are not displayed in the settings.', 'it-acfforms' ); ?></p>

<h4><?php esc_html_e( 'Author', 'it-acfforms' ); ?></h4>

<p><?php printf(
	/* translators: 1: field value 2: setting field label  */
	esc_html__( 'Only displayed if "%1$s" is defined as "%2$s", this field lets you choose the author to assign to new anonymous publications, and is displayed even if author support is disabled for the publication type.', 'it-acfforms' ),
	esc_attr__( 'Everyone', 'it-acfforms' ),
	esc_html__( 'Additional access rights', 'it-acfforms' )
); ?></p>

<h4><?php esc_html_e( 'Fixed or substitute value', 'it-acfforms' ); ?><a id="substitute"></a></h4>

<p><?php esc_html_e( 'Indicate how the field is to be filled in by placing meta keys in braces, substitution variables in percent signs and other characters as they are.', 'it-acfforms' ); ?></p>

<p><?php esc_html_e( 'If a key is not associated with any value, or if the value cannot be interpreted directly (as an array or object), the key between braces or percent signs is returned as is, and will appear in the Post title.', 'it-acfforms' ); ?></p>

<p class="description"><?php printf(
	esc_html__( 'Respect the expected return format values, %s.', 'it-acfforms' ),
	'<a href="#expected-values">'. esc_html__( 'see below for more information', 'it-acfforms' ) .'</a>'
); ?></p>

<h5><?php esc_html_e( 'Substitute variables available', 'it-acfforms' ); ?></h5>
<ul class="ul-disc">
	<li><?php printf(
	/* translators: %s: display_name in code tag */
	esc_html__( '%s: Current user display name', 'it-acfforms' ),
	'<code>display_name</code>'
	); ?>
	</li>
	<li><?php printf(
	/* translators: %s: user_id in code tag  */
	esc_html__( '%s: Current user ID', 'it-acfforms' ),
	'<code>user_id</code>'
	); ?>
	</li>
	<li><?php printf(
	/* translators: %s: date in code tag  */
	esc_html__( '%s: Current date in site Date Format', 'it-acfforms' ),
	'<code>date</code>'
	); ?>
	</li>
	<li><?php printf(
	/* translators: %s: post_type in code tag  */
	esc_html__( '%s: Post Type singular label', 'it-acfforms' ),
	'<code>post_type</code>'
	); ?>
	</li>
</ul>

<h5><?php esc_html_e( 'Examples', 'it-acfforms' ); ?></h5>

<ul class="ul-disc">
	<li><?php printf(
		/* translators: %s: Examples in code tags */
		esc_html__( 'To use a single meta as title, enter the meta key between braces: %s.', 'it-acfforms' ),
		'<code>{custom-title-meta}</code>, <code>{custom-title-field-name}</code>',
	); ?></li>
	<li><?php printf(
		/* translators: %s: Examples in code tags */
		esc_html__( 'To use a single substitution variable as a title, enter it between percent signs: %s.', 'it-acfforms' ),
		'<code>%display_name%</code>, <code>%date%</code>',
	); ?></li>
	<li><?php
	printf(
		/* translators: %s: Examples in code tags */
		esc_html__( 'To use a combination of free characters, meta and substitution keys: %s.', 'it-acfforms' ),
		'<code>{title}, posted by %display_name%</code>, <code>{title} - %date%</code>'
	);
	?></li>
</ul>

<h4><?php esc_html_e( 'Permalink change', 'it-acfforms' ); ?></h4>

<p class="description"><?php printf(
	/* translators: 1: Link to permalinks settings 2: %postname% in code tag */
	esc_html__( 'Theses settings are only available if the %1$s includes the title (%2$s) and only works if a title has been sent by the form.', 'it-acfforms' ),
	'<a href="'. get_admin_url( null, 'options-permalink.php' ) .'">'. esc_html__( 'permalink structure', 'it-acfforms' ) .'</a>',
	'%postname%'
); ?></p>

<p><?php esc_html_e( 'Forcing the permalink to be updated when the title changes means changing the Post URL. This ensures that the URL is consistent with the title, but can lead to 404 errors, which can be detrimental to SEO.', 'it-acfforms' ); ?></p>

<p><?php printf(
	esc_html__( 'The "%s" option defines the default behavior if the choice is not displayed on the form.', 'it-acfforms' ),
	esc_html__( 'Rewrite permalink when title changes', 'it-acfforms' )
); ?></p>

<h4><?php esc_html_e( 'Publication Status and Date, scheduled Posts', 'it-acfforms' ); ?></h4>

<p><?php printf(
	/* translators: %s Scheduled */
	esc_html__( 'If both status and publication date are displayed via default fields and the "%s" option is set to be displayed, an additional option allows the date to be displayed only if this option is selected.', 'it-acfforms' ),
	esc_html__( 'Scheduled' )
); ?></p>

<p><?php printf(
	/* translators: %s Scheduled */
	esc_html__( 'In other cases, the "%s" status may be displayed to improve understanding, but is not necessarily taken into account or necessary:', 'it-acfforms' ),
	esc_html__( 'Scheduled' )
); ?></p>

<ul class="ul-disc">
	<li><?php printf(
	/* translators: %s Scheduled */
	esc_html__( 'If "%s" status is selected but no date is set, the Post will be published.', 'it-acfforms' ),
	esc_html__( 'Scheduled' )
); ?></li>
	<li><?php printf(
	/* translators: 1: Published, 2: Scheduled */
	esc_html__( 'If a date is set in the future, Post will be scheduled, even if the selected status is "%1$s" (or "%2$s" as expected).', 'it-acfforms' ),
	esc_html__( 'Published' ),
	esc_html__( 'Scheduled' )
); ?></li>
</ul>

<p><?php printf(
	/* translators: 1: conditionnal field label 2: field value 3: field label  */
	esc_html__( '%1$s: only displayed if "%2$s" is defined as "%3$s", this field lets you choose the status to assign to new publications.', 'it-acfforms' ),
	'<em>'. esc_html__( 'New Posts status', 'it-acfforms' ) .'</em>',
	esc_html__( 'Do not display or update via the form', 'it-acfforms' ),
	esc_attr__( 'Post status field', 'it-acfforms' )
); ?></p>

<h4><?php esc_html_e( 'Expected return values', 'it-acfforms' ); ?><a id="expected-values"></a></h4>
<p><?php esc_html_e( 'When using custom property fields, respect the expected return values:', 'it-acfforms' ); ?></p>
<ul class="ul-disc">
	<li><?php printf(
		/* translators: 1: field name 2: function used */
		esc_html__( '%1$s: a string (%2$s is used)', 'it-acfforms' ),
		esc_html__( 'Title', 'it-acfforms' ),
		'<code>wp_kses_post</code>',
	); ?></li>
	<li><?php printf(
		/* translators: %s: field name */
		esc_html__( '%s: "1" to adjust permalink on title change, "0" or other not to adjust', 'it-acfforms' ),
		esc_html__( 'Permalink change', 'it-acfforms' ),
	); ?></li>
	<li><?php printf(
		/* translators: %s: field name */
		esc_html__( '%s: an image of the media library (ID, array or URL)', 'it-acfforms' ),
		esc_html__( 'Featured Image', 'it-acfforms' ),
	); ?></li>
	<li><?php printf(
		/* translators: 1: field name 2: function used */
		esc_html__( '%1$s: a string (%2$s is used)', 'it-acfforms' ),
		esc_html__( 'Excerpt', 'it-acfforms' ),
		'<code>sanitize_textarea_field</code>',
	); ?></li>
	<li><?php printf(
		/* translators: 1: field name 2: function used */
		esc_html__( '%1$s: HTML content (%2$s is used)', 'it-acfforms' ),
		esc_html__( 'Editor', 'it-acfforms' ),
		'<code>wp_kses_post</code>',
	); ?></li>
	<li><?php printf(
		/* translators: 1: field name 2: status list */
		esc_html__( '%1$s: one of the following, %2$s', 'it-acfforms' ),
		esc_html__( 'Publication status', 'it-acfforms' ),
		implode( ', ', array_keys( it_acfforms_get_statuses( true ) ) ),
	); ?></li>
	<li><?php printf(
		/* translators: 1: field name 2: expected format 3: function used */
		esc_html__( '%1$s: date and time in format %2$s (%3$s is used)', 'it-acfforms' ),
		esc_html__( 'Publication date', 'it-acfforms' ),
		'"Y-m-d H:i:s"',
		'<code>date_create_from_format</code>',
	); ?></li>
</ul>
