<?php
/*
 * Inserts JS and CSS files.
 */
defined( 'ABSPATH' ) || exit;

/**
 * Inserts custom CSS and toast dependencies and defines the feedback.
 *
 * @since 1.0.0
 * @since 1.0.1 Includes get_plugin_data file if missing.
 */
add_action( 'wp_enqueue_scripts', 'it_acfforms_dependencies', 10, 2 );
function it_acfforms_dependencies() {
	
	if ( ! function_exists('get_plugin_data' ) ) {
		require_once( ABSPATH .'wp-admin/includes/plugin.php' );
	}

	wp_register_style(
		'it_acfforms_css',
		IT_ACFFORMS_URL .'public/css/style.css',
		array(),
		get_plugin_data( IT_ACFFORMS_FILE )['Version']
	);
	wp_enqueue_style( 'it_acfforms_css' );

	if ( array_key_exists( 'it_acfforms_id', $_GET ) ) {

		$post_id = (int) $_GET['it_acfforms_id'];
		$post_type = get_post_type( $post_id );
		$settings = get_option( 'it_acfforms_settings' );
		if ( array_key_exists( $post_type, $settings['post-types'] ) ) {

			wp_register_script(
				'it_acfforms_toast_js',
				IT_ACFFORMS_URL .'public/js/toast.js',
				array( 'jquery' ),
				get_plugin_data( IT_ACFFORMS_FILE )['Version']
			);
			wp_enqueue_script( 'it_acfforms_toast_js' );

			// Defines the feedback message.
			$settings = $settings['post-types'][ $post_type ];
			$feedback = ( ! empty( $_GET['new'] ) ? 'create-feedback' : 'update-feedback' );
			$message = ( ! empty ( $settings[ $feedback ] ) ) ? $settings[ $feedback ] : it_acfforms_get_default_settings( 'post-type' )[ $feedback ];
			$message = str_replace( '%post_status%', get_post_status_object( get_post_status( $post_id ) )->label, $message );
			$message = str_replace( '%post_date%', get_the_date( '', $post_id ), $message );
			wp_localize_script(
				'it_acfforms_toast_js',
				'toast',
				array(
					'message' => $message,
				)
			);
		}
	}
}
