<?php
/*
 * Manages Post types settings and row actions
 */
defined( 'ABSPATH' ) || exit;

/**
 * Creates settings for new Post Type with default settings.
 *
 * @since 1.0.0
 *
 * @param string $post_type        The Post type.
 * @param obj    $post_type_object Arguments used to register the post type.
 */
add_action( 'registered_post_type', 'it_acfforms_registered_post_type', 10, 2 );
function it_acfforms_registered_post_type( $post_type, $post_type_object ) {

	// Acts only on public Post Type.
	if ( true !== $post_type_object->public ) {
		return;
	}

	// Doesn't apply to excluded Post Types.
	if ( in_array( $post_type, it_acfforms_get_excluded_types() ) ) {
		return;
	}

	$settings = get_option( 'it_acfforms_settings' );
	if ( ! array_key_exists( $post_type, $settings['post-types'] ) ) {
		$settings['post-types'][ $post_type ] = it_acfforms_get_default_settings( 'post-type' );
		update_option( 'it_acfforms_settings', $settings );
	}
}

/**
 * Removes from settings Post Types that no longer exist or are excluded.
 *
 * @since 1.0.0
 */
add_action( 'init', 'it_acfforms_unregistered_post_type' );
function it_acfforms_unregistered_post_type() {

	$update_option = false;

	$settings = get_option( 'it_acfforms_settings' );

	foreach ( array_keys( $settings['post-types'] ) as $post_type ) {
		$post_type_object = get_post_type_object( $post_type );
		if ( empty ( $post_type_object ) OR in_array( $post_type, it_acfforms_get_excluded_types() ) ) {
			unset( $settings['post-types'][ $post_type ] );
			$update_option = true;
		}
	}
	if ( $update_option ) {
		update_option( 'it_acfforms_settings', $settings );
	}
}

/**
 * Adds editing link per endpoint.
 *
 * The it_acfforms_get_endpoint_url tests whether the endpoint is active.
 *
 * @since 1.0.0
 */
add_filter( 'page_row_actions', 'it_acfforms_post_row_actions', 10, 2 );
add_filter( 'post_row_actions', 'it_acfforms_post_row_actions', 10, 2 );
function it_acfforms_post_row_actions( $actions, $post ) {
	if ( current_user_can( get_post_type_object( $post->post_type )->cap->edit_post, $post->ID ) ) {
		$url = it_acfforms_get_endpoint_url( $post->ID );
		if ( ! empty( $url ) ) {
			$actions['it-acfforms'] = sprintf(
				'<a href="%1$s">%2$s</a>',
				$url,
				esc_html__( 'Edit in frontend', 'it-acfforms' )
			);
		}
	}
	return $actions;
}
